pub struct StatsSnapshot {
pub hot_cache_entries: u64,
pub hot_cache_bytes: u64,
pub cache_hits: u64,
pub cache_misses: u64,
pub puts: u64,
pub uptime_seconds: u64,
}Fields
hot_cache_entries: u64hot_cache_bytes: u64cache_hits: u64cache_misses: u64puts: u64uptime_seconds: u64Trait Implementations
Sourceimpl Archive for StatsSnapshot
impl Archive for StatsSnapshot
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedStatsSnapshot
type Archived = ArchivedStatsSnapshot
The archived representation of this type. Read more
Sourcetype Resolver = StatsSnapshotResolver
type Resolver = StatsSnapshotResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for StatsSnapshot
impl Clone for StatsSnapshot
Sourcefn clone(&self) -> StatsSnapshot
fn clone(&self) -> StatsSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for StatsSnapshot
Sourceimpl Debug for StatsSnapshot
impl Debug for StatsSnapshot
Sourceimpl<__D: Fallible + ?Sized> Deserialize<StatsSnapshot, __D> for Archived<StatsSnapshot>
impl<__D: Fallible + ?Sized> Deserialize<StatsSnapshot, __D> for Archived<StatsSnapshot>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<StatsSnapshot, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<StatsSnapshot, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for StatsSnapshot
Sourceimpl PartialEq for StatsSnapshot
impl PartialEq for StatsSnapshot
Sourcefn eq(&self, other: &StatsSnapshot) -> bool
fn eq(&self, other: &StatsSnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for StatsSnapshot